@@ -39,7 +39,7 @@
 
 #include "xnconfig.h"
 
-#define LIBRARY_VERSION_MAJOR		17
+#define LIBRARY_VERSION_MAJOR		19
 #define LIBRARY_VERSION_MINOR		0
 #define OPTIONS_DELIMETER		" "
 
@@ -70,7 +70,7 @@ static const char *option_names[] = 	{
 						"PopupExpireTimeout", "CorrectTwoSpaceWithCommaAndSpace","CorrectTwoMinusWithDash",
 						"CorrectCWithCopyright", "CorrectTMWithTrademark", "CorrectRWithRegistered",
 						"CorrectDashWithEmDash","CorrectThreePointsWithEllipsis", "CorrectMisprint", "CheckSimilarWords",
-						"TroubleshootTab",  
+						"TroubleshootTab", "DelaySendingEventApp" 
 					};
 static const char *action_names[] =	{
 						"ChangeWord", "TranslitWord", "ChangecaseWord", "PreviewChangeWord",
@@ -152,9 +152,15 @@ static void parse_line(struct _xneur_config *p, char *line)
 		return;
 	}
 
+	if (line == NULL)
+	{
+		log_message(WARNING, _("Param mismatch for option %s"), option);
+		return;
+	}
+	
 	char *full_string = strdup(line);
-
 	char *param = get_word(&line);
+
 	if (param == NULL)
 	{
 		free(full_string);
@@ -661,7 +667,8 @@ static void parse_line(struct _xneur_config *p, char *line)
 		}
 		case 36: // Log Size
 		{
-			p->size_keyboard_log = atoi (param);
+			if (param != NULL) 
+			  p->size_keyboard_log = atoi (param);
 			break;
 		}
 		case 37: // Log E-Mail 
@@ -979,6 +986,11 @@ static void parse_line(struct _xneur_config *p, char *line)
 			p->troubleshoot_tab = index;
 			break;
 		}
+		case 67: // Get Applications That Event Will Be Delayed Sent events
+		{
+			p->delay_send_key_apps->add(p->delay_send_key_apps, full_string);
+			break;
+		}
 	}
 	free(full_string);
 }
@@ -993,8 +1005,10 @@ static int parse_config_file(struct _xneur_config *p, const char *dir_name, cons
 	}
 
 	for (int i = 0; i < list->data_count; i++)
+	{	
 		parse_line(p, list->data[i].string);
-
+	}
+	
 	list->uninit(list);
 	return TRUE;
 }
@@ -1008,6 +1022,7 @@ static void free_structures(struct _xneur_config *p)
 	p->excluded_apps->uninit(p->excluded_apps);
 	p->autocompletion_excluded_apps->uninit(p->autocompletion_excluded_apps);
 	p->dont_send_key_release_apps->uninit(p->dont_send_key_release_apps);
+	p->delay_send_key_apps->uninit(p->delay_send_key_apps);
 	
 	p->abbreviations->uninit(p->abbreviations);
 	p->plugins->uninit(p->plugins);
@@ -1158,7 +1173,6 @@ static int xneur_config_load(struct _xneur_config *p)
 		log_message(ERROR, _("No languages specified in config file"));
 		return FALSE;
 	}
-
 	return TRUE;
 }
 
@@ -1171,6 +1185,8 @@ static void xneur_config_clear(struct _xneur_config *p)
 	p->auto_apps			= list_char_init();
 	p->layout_remember_apps		= list_char_init();
 	p->dont_send_key_release_apps	= list_char_init();
+	p->delay_send_key_apps	= list_char_init();
+	
 	p->excluded_apps		= list_char_init();
 	p->autocompletion_excluded_apps	= list_char_init();
 	p->abbreviations		= list_char_init();
@@ -1348,6 +1364,14 @@ static int xneur_config_save(struct _xneur_config *p)
 	fprintf(stream, "# Example:\n");
 	fprintf(stream, "#RotateLayoutAfterChangeSelectedMode No\n");
 	fprintf(stream, "RotateLayoutAfterChangeSelectedMode %s\n\n", p->get_bool_name(p->rotate_layout_after_convert));
+
+	fprintf(stream, "# Add Applications names to include it to delay sending process\n");
+	fprintf(stream, "# Xneur will be delay KeyPress and KeyRelease events for this applications\n");
+	fprintf(stream, "# Example:\n");
+	fprintf(stream, "#DelaySendingEventApp Firefox\n");
+	for (int i = 0; i < p->delay_send_key_apps->data_count; i++)
+		fprintf(stream, "DelaySendingEventApp %s\n", p->delay_send_key_apps->data[i].string);
+	fprintf(stream, "\n");
 	
 	fprintf(stream, "# This option define delay before sendind events to application (in milliseconds between 0 to 50).\n");
 	fprintf(stream, "SendDelay %d\n\n", p->send_delay);
@@ -1651,6 +1675,9 @@ struct _xneur_config* xneur_config_init(void)
 	p->pid = -1;
 	
 	p->handle = xneur_handle_create();
+
+	//char *a = "ghbdtn";
+	//xneur_get_layout(p->handle, a);
 	
 	p->hotkeys = (struct _xneur_hotkey *) malloc(MAX_HOTKEYS * sizeof(struct _xneur_hotkey));
 	bzero(p->hotkeys, MAX_HOTKEYS * sizeof(struct _xneur_hotkey));
@@ -1674,6 +1701,7 @@ struct _xneur_config* xneur_config_init(void)
 	p->manual_apps			= list_char_init();
 	p->layout_remember_apps		= list_char_init();
 	p->dont_send_key_release_apps = list_char_init();
+	p->delay_send_key_apps	= list_char_init();
 	
 	p->window_layouts		= list_char_init();
 	p->abbreviations		= list_char_init();
