@@ -18,6 +18,8 @@
  */
 
 #include <X11/XKBlib.h>
+//#include <X11/Xlib.h>
+//#include <X11/extensions/XTest.h>
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -75,7 +77,16 @@ int get_key_state(int key)
 
 void event_send_xkey(struct _event *p, KeyCode kc, int modifiers)
 {
-	usleep(xconfig->send_delay);
+	//XTestGrabControl (main_window->display, True);
+	
+	char *app_name = NULL;
+	app_name = get_wm_class_name(p->owner_window);
+	
+	int is_delay = xconfig->delay_send_key_apps->exist(xconfig->delay_send_key_apps, app_name, BY_PLAIN);
+	if (is_delay)
+	{
+		usleep(xconfig->send_delay * 1000);
+	}
 	
 	p->event.type			= KeyPress;
 	p->event.xkey.type		= KeyPress;
@@ -87,28 +98,38 @@ void event_send_xkey(struct _event *p, KeyCode kc, int modifiers)
 	p->event.xkey.state		= modifiers;
 	p->event.xkey.keycode		= kc;
 	p->event.xkey.time		= CurrentTime;
-
-	char *app_name = NULL;
-	app_name = get_wm_class_name(p->owner_window);	
+		
 	if (xconfig->dont_send_key_release_apps->exist(xconfig->dont_send_key_release_apps, app_name, BY_PLAIN))
 	{
 		XSendEvent(main_window->display, p->owner_window, TRUE, NoEventMask, &p->event);
+		XFlush(main_window->display);
 		log_message(TRACE, _("The event KeyRelease is not sent to the window (ID %d) with name '%s'"), p->owner_window, app_name);
+		if (app_name != NULL)
+			free(app_name);
 		return;
 	}
 
 	XSendEvent(main_window->display, p->owner_window, TRUE, NoEventMask, &p->event);
+	XFlush(main_window->display);
+	
+	if (is_delay)
+	{
+		usleep(xconfig->send_delay * 1000);
+	}
 	
 	p->event.type			= KeyRelease;
 	p->event.xkey.type		= KeyRelease;
 	p->event.xkey.time		= CurrentTime;
 
 	XSendEvent(main_window->display, p->owner_window, TRUE, NoEventMask, &p->event);
+	XFlush(main_window->display);
+	//XTestGrabControl (main_window->display, False);
+	if (app_name != NULL)
+		free(app_name);
 }
 
 static void event_send_backspaces(struct _event *p, int count)
 {
-
 	for (int i = 0; i < count; i++)
 	{
 		p->send_xkey(p, p->backspace, None);
@@ -117,7 +138,6 @@ static void event_send_backspaces(struct _event *p, int count)
 
 static void event_send_spaces(struct _event *p, int count)
 {
-	
 	for (int i = 0; i < count; i++)
 	{
 		p->send_xkey(p, p->space, None);
@@ -148,15 +168,20 @@ static KeySym event_get_cur_keysym(struct _event *p)
 {
 	//return XLookupKeysym(&p->event.xkey, 0);
 	
-	/*KeySym ks;
-    int nbytes = 0;
+	KeySym ks;
+
+	/*int nbytes = 0;
     char str[256+1];
 	XKeyEvent *e = (XKeyEvent *) &p->event;
     nbytes = XLookupString (e, str, 256, &ks, NULL);
+	if (nbytes) {};
 	return ks;*/
 
 	XKeyEvent *e = (XKeyEvent *) &p->event;
-	return XkbKeycodeToKeysym(main_window->display, e->keycode, 0, 0);
+	ks = XkbKeycodeToKeysym(main_window->display, e->keycode, main_window->keymap->latin_group, 0);
+	if (ks == NoSymbol) 
+		ks = XkbKeycodeToKeysym(main_window->display, e->keycode, 0, 0);
+	return ks;
 }
 
 static int event_get_cur_modifiers(struct _event *p)
