@@ -204,10 +204,10 @@ int get_keycode_mod(int group)
 
 static void keymap_get_keysyms_by_string(struct _keymap *p, char *keyname, KeySym *lower, KeySym *upper)
 {
+	*lower = NoSymbol;
+	*upper = NoSymbol;
 	if (keyname == NULL)
 	{
-		*lower = NoSymbol;
-		*upper = NoSymbol;
 		return;
 	}
 
@@ -217,7 +217,9 @@ static void keymap_get_keysyms_by_string(struct _keymap *p, char *keyname, KeySy
 
 	for (int i = p->min_keycode; i <= p->max_keycode; i++)
 	{
-		for (int j = 0; j < 2; j++)
+		int max = p->keysyms_per_keycode - 1;
+
+		for (int j = 0; j <= max; j++)
 		{
 			if (p->keymap[j] == NoSymbol)
 				continue;
@@ -328,10 +330,9 @@ static char keymap_get_ascii_real(struct _keymap *p, const char *sym, int* prefe
 
 						size_t _symbol_len = strlen(symbol);
 
-						event.xkey.state = 0;
+						event.xkey.state = get_keycode_mod(p->latin_group);
 						event.xkey.state |= state_masks[m];
 						event.xkey.state |= state_masks[n];
-
 						nbytes = XLookupString((XKeyEvent *) &event, symbol, 256, NULL, NULL);
 						if (nbytes <= 0)
 							continue;
@@ -341,6 +342,9 @@ static char keymap_get_ascii_real(struct _keymap *p, const char *sym, int* prefe
 						free(prev_symbols);
 						free(symbol);
 						*kc		= event.xkey.keycode;
+						event.xkey.state = 0;
+						event.xkey.state |= state_masks[m];
+						event.xkey.state |= state_masks[n];
 						*modifier	= get_keycode_mod(lang) | event.xkey.state;
 						if (symbol_len)
 							*symbol_len = _symbol_len;
@@ -366,7 +370,7 @@ static char keymap_get_ascii(struct _keymap *p, const char *sym, int* preferred_
 	int _preferred_lang = 0;
 	if (preferred_lang)
 		_preferred_lang = *preferred_lang;
-
+	
 	size_t sym_size = strlen(sym);
 
 	/* Look up cache */
@@ -423,7 +427,7 @@ static char keymap_get_cur_ascii_char(struct _keymap *p, XEvent e)
 		mod |= NumlockMask;
 	
 	char *symbol = (char *) malloc((256 + 1) * sizeof(char));
-
+	
 	ke->state = get_keycode_mod(p->latin_group);
 	ke->state |= mod;
 
@@ -442,14 +446,13 @@ static char keymap_get_cur_ascii_char(struct _keymap *p, XEvent e)
 static void keymap_convert_text_to_ascii(struct _keymap *p, char *text, KeyCode *kc, int *kc_mod)
 {
 	int text_len = strlen(text);
-
 	int j = 0;
 	size_t symbol_len = 0;
 	int preferred_lang = 0;
+
 	for (int i = 0; i < text_len; i += symbol_len)
 	{
 		char new_symbol = p->get_ascii(p, &text[i], &preferred_lang, &kc[j], &kc_mod[j], &symbol_len);
-
 		if (new_symbol != NULLSYM && symbol_len > 0)
 			text[j++] = new_symbol;
 		else
@@ -563,7 +566,6 @@ static void get_offending_modifiers (struct _keymap *p)
 	p->scrolllock_mask = 0;
 	p->capslock_mask = 0;
 	
-	int i;
 	XModifierKeymap *modmap;
 	KeyCode nlock, slock;
 	static int mask_table[8] = {
@@ -582,7 +584,7 @@ static void get_offending_modifiers (struct _keymap *p)
 
 	if (modmap != NULL && modmap->max_keypermod > 0)
 	{
-		for (i = 0; i < 8 * modmap->max_keypermod; i++)
+		for (int i = 0; i < 8 * modmap->max_keypermod; i++)
 		{
 			if (modmap->modifiermap[i] == nlock && nlock != 0)
 				p->numlock_mask = mask_table[i / modmap->max_keypermod];
@@ -639,7 +641,15 @@ struct _keymap* keymap_init(struct _xneur_handle *handle, Display *display)
 	p->symbol_to_keycode_cache_pos = 0;
 
 	get_offending_modifiers(p);
-
+	for (int i = 0; i < p->handle->total_languages; i++)
+	{
+		// FIXME Replace hardcode "us" to setting
+		if (strcmp(p->handle->languages[i].dir, "us") == 0)
+		{
+			p->latin_group = i;
+		}
+	}
+	
 	p->purge_caches			= keymap_purge_caches;
 	p->get_keysyms_by_string	= keymap_get_keysyms_by_string;
 	p->keycode_to_symbol		= keymap_keycode_to_symbol;
