@@ -21,11 +21,12 @@
 #define _UTILS_H_
 
 #include <X11/XKBlib.h>
+#include <X11/extensions/XInput2.h>
 
 void   set_event_mask(Window window, int event_mask);
 void   set_mask_to_window(Window window, int event_mask);
 char*  get_wm_class_name(Window window);
-void   grab_button(int is_grab);
+void   grab_button(Window window, int is_grab);
 void   grab_keyboard(Window window, int is_grab);
 void   grab_key(Window window, KeyCode kc, int is_grab);
 void   grab_spec_keys(Window window, int is_grab);
