@@ -72,7 +72,7 @@ void sound_uninit(void)
 	It is normally not needed to call this function in a normal application as
 	the resources will automatically be freed when the program terminates.
 	*/
-	gst_deinit();
+	//gst_deinit();
 }
 
 static gboolean bus_call(GstBus *bus, GstMessage *msg, gpointer data)
@@ -85,6 +85,7 @@ static gboolean bus_call(GstBus *bus, GstMessage *msg, gpointer data)
 	{
 		case GST_MESSAGE_EOS:
 		{
+		    //g_print ("End of stream\n");
 			g_main_loop_quit(loop);
 			break;
 		}
@@ -95,6 +96,7 @@ static gboolean bus_call(GstBus *bus, GstMessage *msg, gpointer data)
 
 			gst_message_parse_error(msg, &err, &debug);
 			g_free(debug);
+			g_printerr ("Error: %s\n", err->message);
 			g_error_free(err);
 
 			g_main_loop_quit(loop);
@@ -107,15 +109,21 @@ static gboolean bus_call(GstBus *bus, GstMessage *msg, gpointer data)
 	return TRUE;
 }
 
-static void new_pad(GstElement *element, GstPad *pad, gpointer data)
+static void on_pad_added(GstElement *element, GstPad *pad, gpointer data)
 {
 	if (element){}
 
-	GstElement *sink = data;
+	GstPad *sinkpad;
+	GstElement *decoder = (GstElement *) data;
 
-	GstPad *alsapad = gst_element_get_pad(sink, "sink");
-	gst_pad_link(pad, alsapad);
-	gst_object_unref(alsapad);
+	// We can now link this pad with the vorbis-decoder sink pad 
+	//g_print ("Dynamic pad created, linking demuxer/decoder\n");
+
+	sinkpad = gst_element_get_static_pad (decoder, "sink");
+
+	gst_pad_link (pad, sinkpad);
+
+	gst_object_unref (sinkpad);
 }
 
 void *play_file_thread(void *param)
@@ -123,26 +131,25 @@ void *play_file_thread(void *param)
 	char *path = (char *) param;
 	log_message(TRACE, _("Play sound sample %s (use Gstreamer engine)"), path);
 
+
 	// Initialize GStreamer
 	GMainLoop *loop = g_main_loop_new(NULL, FALSE);
 
-	// Initialize gst-elements
-	GstElement *pipeline = gst_pipeline_new        ("xneur");
-	GstElement *source   = gst_element_factory_make("filesrc",  "file-source");
-	GstElement *parser   = gst_element_factory_make("wavparse", "wav-parcer");
-	GstElement *volume   = gst_element_factory_make("volume", "volume");
-	GstElement *conv     = gst_element_factory_make("audioconvert",  "converter");
-	GstElement *sink     = gst_element_factory_make("alsasink", "audio-output");
-	
-	if (!pipeline || !source || !parser || !conv || !volume || !sink)
-	{
-		free(path);
-		log_message(ERROR, _("Failed to create gstreamer context"));
-		g_main_loop_unref(loop);
-		return NULL;
-  	}
+	GstElement *pipeline, *source, *demuxer, *decoder, *conv, *sink, *volume;
+	GstBus *bus;
+	guint bus_watch_id;
+	/* Create gstreamer elements */
+	pipeline = gst_pipeline_new ("audio-player");
+	gst_element_set_state (pipeline, GST_STATE_NULL);
 
-	/*if (!pipeline)
+	source   = gst_element_factory_make ("filesrc", NULL);
+	demuxer = gst_element_factory_make("decodebin", NULL);
+	decoder = gst_element_factory_make("audioconvert", NULL);
+	conv     = gst_element_factory_make ("audioconvert",  NULL);
+	sink     = gst_element_factory_make ("autoaudiosink", NULL);
+	volume = gst_element_factory_make("volume", NULL);
+
+	if (!pipeline)
 	{
 		free(path);
 		log_message(ERROR, _("Failed to create gstreamer context (pipeline)"));
@@ -158,14 +165,22 @@ void *play_file_thread(void *param)
 		return NULL;
   	}
 	
-	if (!parser)
+	if (!demuxer)
 	{
 		free(path);
-		log_message(ERROR, _("Failed to create gstreamer context (parser)"));
+		log_message(ERROR, _("Failed to create gstreamer context (demuxer)"));
 		g_main_loop_unref(loop);
 		return NULL;
   	}
 
+	if (!decoder)
+	{
+		free(path);
+		log_message(ERROR, _("Failed to create gstreamer context (decoder)"));
+		g_main_loop_unref(loop);
+		return NULL;
+  	}
+	
 	if (!conv)
 	{
 		free(path);
@@ -188,37 +203,51 @@ void *play_file_thread(void *param)
 		log_message(ERROR, _("Failed to create gstreamer context (sink)"));
 		g_main_loop_unref(loop);
 		return NULL;
-  	}*/
-	
-	g_object_set(G_OBJECT(source), "location", path, NULL);
+  	}
+
+	// Set volume
 	double i = (double) xconfig->volume_percent / 100.0;
 	g_object_set (G_OBJECT (volume), "volume", (double)i, NULL);
-	
-	GstBus *bus = gst_pipeline_get_bus(GST_PIPELINE(pipeline));
-	gst_bus_add_watch(bus, bus_call, loop);
-	gst_object_unref(bus);
-	
-	gst_bin_add_many(GST_BIN(pipeline), source, parser, conv, volume, sink, NULL);
-	
-	gst_element_link(source, parser);
-	gst_element_link_many (conv, volume, sink, NULL);
-	
-	g_signal_connect(parser, "pad-added", G_CALLBACK(new_pad), conv);
 
-	gst_element_set_state(pipeline, GST_STATE_PLAYING);
-	g_main_loop_run(loop);
+	/* we set the input filename to the source element */
+	g_object_set (G_OBJECT (source), "location", path, NULL);
 
-	// Clean up nicely
-	gst_element_set_state(pipeline, GST_STATE_NULL);
-	gst_object_unref(GST_OBJECT(pipeline));
-	g_main_loop_unref(loop);
-	
+	g_signal_connect(demuxer, "pad-added", G_CALLBACK(on_pad_added), decoder);
+
+	gst_bin_add_many (GST_BIN (pipeline), source, demuxer, decoder, volume, conv, sink, NULL);
+
+	gst_element_link (source, demuxer);
+	gst_element_link_many (decoder, volume, conv, sink, NULL);  
+   
+	/* we add a message handler */
+	bus = gst_pipeline_get_bus (GST_PIPELINE (pipeline));
+	bus_watch_id = gst_bus_add_watch (bus, bus_call, loop);
+	gst_object_unref (bus);
+
+
+	/* Set the pipeline to "playing" state*/
+	//g_print ("Now playing: %s\n", path);
+	gst_element_set_state (pipeline, GST_STATE_PLAYING);
+
+	/* Iterate */
+	//g_print ("Running...\n");
+	g_main_loop_run (loop);
+
+	/* Out of the main loop, clean up nicely */
+	//g_print ("Returned, stopping playback\n");
+	gst_element_set_state (pipeline, GST_STATE_NULL);
+
+	//g_print ("Deleting pipeline\n");
+	gst_object_unref (GST_OBJECT (pipeline));
+	g_source_remove (bus_watch_id);
+	g_main_loop_unref (loop);
+			
 	free(path);
 	
 	return NULL;
 }
 
-#elif WITH_OPENAL /* WITH_GSTREAMER */
+#elif WITH_OPENAL /* WITH_OPENAL */
 
 void sound_init(void)
 {
